@@ -3,19 +3,22 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * The contents of this file constitute Original Code as defined in and
- * are subject to the Apple Public Source License Version 1.1 (the
- * "License").  You may not use this file except in compliance with the
- * License.  Please obtain a copy of the License at
- * http://www.apple.com/publicsource and read it before using this file.
+ * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
  * 
- * This Original Code and all software distributed under the License are
- * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This file contains Original Code and/or Modifications of Original Code
+ * as defined in and that are subject to the Apple Public Source License
+ * Version 2.0 (the 'License'). You may not use this file except in
+ * compliance with the License. Please obtain a copy of the License at
+ * http://www.opensource.apple.com/apsl/ and read it before using this
+ * file.
+ * 
+ * The Original Code and all software distributed under the License are
+ * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
- * License for the specific language governing rights and limitations
- * under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
+ * Please see the License for the specific language governing rights and
+ * limitations under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -28,36 +31,40 @@
 //
 
 // System Includes
-#include <servers/netname.h>
-#include <sys/types.h>
-#include <sys/wait.h>
-#include <sys/sysctl.h>
-#include <dev/disk.h>
-#include <fcntl.h>
-#include <sys/errno.h>
-#include <mach/mach_init.h>
-#include <sys/loadable_fs.h>
 #include <stdio.h>
 #include <unistd.h>
 #include <string.h>
 #include <stdlib.h>
+#include <fcntl.h>
+#include <dirent.h>
+#include <architecture/byte_order.h>
+#include <mach/mach_init.h>
+#include <servers/netname.h>
+#include <sys/types.h>
+#include <sys/wait.h>
+#include <sys/sysctl.h>
+#include <sys/disk.h>
+#include <sys/errno.h>
+#include <sys/paths.h>
 #include <sys/stat.h>
 #include <sys/time.h>
 #include <sys/mount.h>
-#include <dirent.h>
-#include <architecture/byte_order.h>
+#include <sys/loadable_fs.h>
 
 // CoreFoundation Includes
 #include <CoreFoundation/CoreFoundation.h>
+#include <CoreFoundation/CFPriv.h>
 
 // IOKit Includes
 #include <IOKit/IOKitLib.h>
+#include <IOKit/storage/IOCDMedia.h>
 
 // Project includes
 #include "cddafs_util.h"
 #include "mntopts.h"
 #include "AppleCDDAFileSystemDefines.h"
 
+	#include "CDDATrackName.h"
 
 
 //
@@ -474,9 +481,7 @@ Probe ( char * deviceNamePtr )
 	{
 		
 		CFStringRef			albumName 			= 0;
-		UInt8				albumNameSize		= 0;
 		CDDATrackName *		database 			= NULL;
-		char				name[2048];
 		
 		database = new CDDATrackName;
 		
@@ -494,29 +499,24 @@ Probe ( char * deviceNamePtr )
 			
 		}
 		
-		#if DEBUG
-		CFShow ( albumName );
-		#endif
-		
 		if ( albumName != 0 )
 		{
 			
-			albumNameSize = CFStringGetLength ( albumName );
+			Boolean		success				= false;
+			char		buffer[MAXNAMLEN];
 			
-		}
-		
-		// Make sure we fit into a MAXNAMLEN sized string
-		if ( ( albumNameSize < MAXNAMLEN ) && ( albumNameSize != 0 ) )
-		{
+			#if DEBUG
+			CFShow ( albumName );
+			#endif
 			
-			// Just use the album name for now.
-			Boolean	result;
+			success = _CFStringGetFileSystemRepresentation ( albumName,
+														     ( UInt8 * ) buffer,
+															 MAXNAMLEN );
 			
-			result = CFStringGetCString ( albumName, name, sizeof ( name ), kCFStringEncodingUTF8 );
-			if ( result == true )
+			if ( success == true )
 			{
 				
-				WriteDiskLabel ( name );
+				WriteDiskLabel ( buffer );
 				
 			}
 			
@@ -528,6 +528,10 @@ Probe ( char * deviceNamePtr )
 				
 			}
 			
+			// release it
+			CFRelease ( albumName );
+			albumName = 0;
+			
 		}
 		
 		else
@@ -538,11 +542,6 @@ Probe ( char * deviceNamePtr )
 			
 		}
 		
-		if ( albumName != 0 )
-		{
-			CFRelease ( albumName );
-		}
-		
 		if ( database != NULL )
 		{
 			
@@ -1120,6 +1119,7 @@ GetTrackData ( const char * 				bsdDevNode,
 	
 	data 		= CFDataCreateMutable ( kCFAllocatorDefault, 0 );
 	
+	database	= new CDDATrackName;
 	
 	database->Init ( bsdDevNode, TOCData );
 	
@@ -1144,34 +1144,27 @@ GetTrackData ( const char * 				bsdDevNode,
 		if ( trackString != 0 )
 		{
 			
-			CFIndex		numCharsConverted 	= 0;
-			CFIndex		numChars 			= 0;
 			UInt32		size 				= 0;
 			UInt8		tmp					= 0;
+			Boolean		success				= false;
 			char		buffer[MAXNAMLEN];
 			
-			size = CFStringGetLength ( trackString );
+			success = _CFStringGetFileSystemRepresentation ( trackString,
+														     ( UInt8 * ) buffer,
+															 MAXNAMLEN );
+			
+			size = strlen ( buffer );
 			
 			DebugLog ( ( "size = %ld\n", size ) );
 			
-			numCharsConverted = CFStringGetBytes (
-									trackString,
-									CFRangeMake ( 0, CFStringGetLength ( trackString ) ),
-									kCFStringEncodingUTF8,
-									0,
-									false,
-									( UInt8 * ) buffer,
-									MAXNAMLEN,
-									&numChars );
-			
-			DebugLog ( ( "numChars = %ld, numCharsConverted = %ld\n", numChars, numCharsConverted ) );
-			
 			// add the track number to the data object
 			CFDataAppendBytes ( data,
 								&currentTrack,
 								1 );
 			
-			tmp = numChars & 0xFF;
+			// Size better be less than MAXNAMLEN!
+			tmp = size & 0x000000FF;
+			
 			// add the size to the data object
 			CFDataAppendBytes ( data,
 								&tmp,
@@ -1668,7 +1661,7 @@ GetTOCDataPtr ( const char * deviceNamePtr )
 				
 				// Get the TOCInfo
 				data = ( CFDataRef ) CFDictionaryGetValue ( properties, 
-															CFSTR ( kIOCDMediaTOC ) );
+															CFSTR ( kIOCDMediaTOCKey ) );
 				if ( data != NULL )
 				{
 					
